==> ejc-businessplan-impl-3.0.0-20220329.134247-55-sources.jar: com/ejianc/business/record/bean/RecordFundsplanningEntity.java <==
package com.ejianc.business.record.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
/**
 * 项目资金管理策划变更记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_businessplan_fundsplanning")
public class RecordFundsplanningEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="agent_id")
    private Long agentId; // 经办人id
    @TableField(value="agent_name")
    private String agentName; // 经办人名称
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value = "change_reason")
    private String changeReason;
    @TableField(value = "effect_time")
    private Date effectTime;

    public Date getEffectTime() {
        return effectTime;
    }

    public void setEffectTime(Date effectTime) {
        this.effectTime = effectTime;
    }

    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="recordFundsplanningdetailService",pidName = "mid")
    private List<RecordFundsplanningdetailEntity> recordFundsplanningdetailEntities = new ArrayList<>(); // 项目资金管理策划变更记录子表
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
    /**
     * 项目资金管理策划变更记录子表
     */
    public List<RecordFundsplanningdetailEntity> getRecordFundsplanningdetailEntities() {
        return recordFundsplanningdetailEntities;
    }

    /**
     * 项目资金管理策划变更记录子表
     */
    public void setRecordFundsplanningdetailEntities(List<RecordFundsplanningdetailEntity> recordFundsplanningdetailEntities) {
        this.recordFundsplanningdetailEntities = recordFundsplanningdetailEntities;
    }
}

==> ejc-businessplan-impl-3.0.0-20251128.085009-234-sources.jar: com/ejianc/business/record/bean/RecordFundsplanningEntity.java <==
package com.ejianc.business.record.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
/**
 * 项目资金管理策划变更记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_businessplan_fundsplanning")
public class RecordFundsplanningEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="agent_id")
    private Long agentId; // 经办人id
    @TableField(value="agent_name")
    private String agentName; // 经办人名称
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value = "change_reason")
    private String changeReason;
    @TableField(value = "effect_time")
    private Date effectTime;
    @TableField(value = "fundsplanning_id")
    private Long fundsplanningId;

    public Long getFundsplanningId() {
        return fundsplanningId;
    }

    public void setFundsplanningId(Long fundsplanningId) {
        this.fundsplanningId = fundsplanningId;
    }

    public Date getEffectTime() {
        return effectTime;
    }

    public void setEffectTime(Date effectTime) {
        this.effectTime = effectTime;
    }

    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="recordFundsplanningdetailService",pidName = "mid")
    private List<RecordFundsplanningdetailEntity> recordFundsplanningdetailEntities = new ArrayList<>(); // 项目资金管理策划变更记录子表
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
    /**
     * 项目资金管理策划变更记录子表
     */
    public List<RecordFundsplanningdetailEntity> getRecordFundsplanningdetailEntities() {
        return recordFundsplanningdetailEntities;
    }

    /**
     * 项目资金管理策划变更记录子表
     */
    public void setRecordFundsplanningdetailEntities(List<RecordFundsplanningdetailEntity> recordFundsplanningdetailEntities) {
        this.recordFundsplanningdetailEntities = recordFundsplanningdetailEntities;
    }
}
